import { getDefaultLocale } from './locales';

const formatterCache = {};

/**
 * Gets Intl-based date formatter from formatter cache. If it doesn't exist in cache
 * just yet, it will be created on the fly.
 */
const getFormatter = (options, locale) => {
  if (!locale) {
    // Default parameter is not enough as it does not protect us from null values
    // eslint-disable-next-line no-param-reassign
    locale = getDefaultLocale();
  }

  const stringifiedOptions = JSON.stringify(options);

  if (!formatterCache[locale]) {
    formatterCache[locale] = {};
  }

  if (!formatterCache[locale][stringifiedOptions]) {
    formatterCache[locale][stringifiedOptions] = new Intl.DateTimeFormat(locale, options).format;
  }

  return formatterCache[locale][stringifiedOptions];
};

export const formatDate = (date, locale) => getFormatter(
  { day: 'numeric', month: 'numeric', year: 'numeric' },
  locale,
)(date);

export const formatTime = (date, locale) => getFormatter(
  { hour: 'numeric', minute: 'numeric', second: 'numeric' },
  locale,
)(date);

export const formatDateTime = (date, locale) => getFormatter(
  {
    day: 'numeric',
    month: 'numeric',
    year: 'numeric',
    hour: 'numeric',
    minute: 'numeric',
    second: 'numeric',
  },
  locale,
)(date);
